@@ -43,7 +43,7 @@ public:
 
     void load(const KCalendarCore::Incidence::Ptr &incidence) override;
     void save(const KCalendarCore::Incidence::Ptr &incidence) override;
-    Q_REQUIRED_RESULT bool isDirty() const override;
+    [[nodiscard]] bool isDirty() const override;
     void printDebugInfo() const override;
 
     AttendeeTableModel *dataModel() const;
@@ -52,7 +52,7 @@ public:
     AttendeeComboBoxDelegate *responseDelegate() const;
     AttendeeLineEditDelegate *attendeeDelegate() const;
 
-    Q_REQUIRED_RESULT int attendeeCount() const;
+    [[nodiscard]] int attendeeCount() const;
 
 Q_SIGNALS:
     void attendeeCountChanged(int);
@@ -64,7 +64,7 @@ public Q_SLOTS:
     void declineForMe();
 
 private Q_SLOTS:
-    // cheks if row is a group,  that can/should be expanded
+    // checks if row is a group,  that can/should be expanded
     void checkIfExpansionIsNeeded(const KCalendarCore::Attendee &attendee);
 
     // results of the group search job
@@ -96,6 +96,8 @@ private Q_SLOTS:
     void slotGroupSubstitutionAttendeeChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight);
     void slotGroupSubstitutionLayoutChanged();
 
+    void slotUpdateCryptoPreferences();
+
 private:
     void updateGroupExpand();
 
@@ -139,4 +141,3 @@ private:
     QMap<KJob *, QString> mExpandGroupJobs;
 };
 }
-
