@@ -10,81 +10,79 @@
 #include "ui_resourcemanagement.h"
 #include <CalendarSupport/FreeBusyItem>
 
-#include "freebusyganttproxymodel.h"
-
-#include <Akonadi/Calendar/FreeBusyManager>
+#include <Akonadi/FreeBusyManager>
 
 #include <EventViews/AgendaView>
 
 #include <KCalendarCore/Event>
-#include <KCalendarCore/MemoryCalendar>
-
-#include <KGantt/KGanttGraphicsView>
 
 #include <KConfigGroup>
 #include <KLocalizedString>
 #include <KSharedConfig>
 
+#include <KWindowConfig>
 #include <QColor>
 #include <QDialogButtonBox>
 #include <QLabel>
 #include <QPushButton>
 #include <QStringList>
+#include <QWindow>
 
 using namespace IncidenceEditorNG;
-
+namespace
+{
+static const char myResourceManagementConfigGroupName[] = "ResourceManagement";
+}
 class FreebusyViewCalendar : public EventViews::ViewCalendar
 {
 public:
-    ~FreebusyViewCalendar() override
-    {
-    }
+    ~FreebusyViewCalendar() override = default;
 
-    bool isValid(const KCalendarCore::Incidence::Ptr &incidence) const override
+    [[nodiscard]] bool isValid(const KCalendarCore::Incidence::Ptr &incidence) const override
     {
         return isValid(incidence->uid());
     }
 
-    bool isValid(const QString &incidenceIdentifier) const override
+    [[nodiscard]] bool isValid(const QString &incidenceIdentifier) const override
     {
         return incidenceIdentifier.startsWith(QLatin1String("fb-"));
     }
 
-    QString displayName(const KCalendarCore::Incidence::Ptr &incidence) const override
+    [[nodiscard]] QString displayName(const KCalendarCore::Incidence::Ptr &incidence) const override
     {
         Q_UNUSED(incidence)
         return QStringLiteral("Freebusy");
     }
 
-    QColor resourceColor(const KCalendarCore::Incidence::Ptr &incidence) const override
+    [[nodiscard]] QColor resourceColor(const KCalendarCore::Incidence::Ptr &incidence) const override
     {
         bool ok = false;
         int status = incidence->customProperty(QStringLiteral("FREEBUSY").toLatin1(), QStringLiteral("STATUS").toLatin1()).toInt(&ok);
 
         if (!ok) {
-            return QColor(85, 85, 85);
+            return {85, 85, 85};
         }
 
         switch (status) {
         case KCalendarCore::FreeBusyPeriod::Busy:
-            return QColor(255, 0, 0);
+            return {255, 0, 0};
         case KCalendarCore::FreeBusyPeriod::BusyTentative:
         case KCalendarCore::FreeBusyPeriod::BusyUnavailable:
-            return QColor(255, 119, 0);
+            return {255, 119, 0};
         case KCalendarCore::FreeBusyPeriod::Free:
-            return QColor(0, 255, 0);
+            return {0, 255, 0};
         default:
-            return QColor(85, 85, 85);
+            return {85, 85, 85};
         }
     }
 
-    QString iconForIncidence(const KCalendarCore::Incidence::Ptr &incidence) const override
+    [[nodiscard]] QString iconForIncidence(const KCalendarCore::Incidence::Ptr &incidence) const override
     {
         Q_UNUSED(incidence)
-        return QString();
+        return {};
     }
 
-    KCalendarCore::Calendar::Ptr getCalendar() const override
+    [[nodiscard]] KCalendarCore::Calendar::Ptr getCalendar() const override
     {
         return mCalendar;
     }
@@ -96,7 +94,7 @@ ResourceManagement::ResourceManagement(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Resource Management"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -107,7 +105,7 @@ ResourceManagement::ResourceManagement(QWidget *parent)
 
     mUi = new Ui_resourceManagement;
 
-    QWidget *w = new QWidget(this);
+    auto w = new QWidget(this);
     mUi->setupUi(w);
     auto mainLayout = new QVBoxLayout(this);
     mainLayout->addWidget(w);
@@ -153,17 +151,17 @@ ResourceManagement::~ResourceManagement()
 
 void ResourceManagement::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "ResourceManagement");
-    const QSize size = group.readEntry("Size", QSize(600, 400));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myResourceManagementConfigGroupName));
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void ResourceManagement::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openConfig(), "ResourceManagement");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), QLatin1String(myResourceManagementConfigGroupName));
+    KWindowConfig::saveWindowSize(windowHandle(), group);
     group.sync();
 }
 
@@ -179,12 +177,12 @@ void ResourceManagement::slotStartSearch(const QString &text)
 
 void ResourceManagement::slotShowDetails(const QModelIndex &current)
 {
-    ResourceItem::Ptr item = current.model()->data(current, ResourceModel::Resource).value<ResourceItem::Ptr>();
+    auto item = current.model()->data(current, ResourceModel::Resource).value<ResourceItem::Ptr>();
     mSelectedItem = item;
     showDetails(item->ldapObject(), item->ldapClient());
 }
 
-void ResourceManagement::showDetails(const KLDAP::LdapObject &obj, const KLDAP::LdapClient &client)
+void ResourceManagement::showDetails(const KLDAPCore::LdapObject &obj, const KLDAPWidgets::LdapClient &client)
 {
     // Clean up formDetails
     QLayoutItem *child = nullptr;
@@ -203,7 +201,7 @@ void ResourceManagement::showDetails(const KLDAP::LdapObject &obj, const KLDAP::
             QStringList attrs;
             attrs << QStringLiteral("cn") << QStringLiteral("mail") << QStringLiteral("mobile") << QStringLiteral("telephoneNumber")
                   << QStringLiteral("kolabDescAttribute") << QStringLiteral("description");
-            mOwnerItem = ResourceItem::Ptr(new ResourceItem(KLDAP::LdapDN(QString::fromUtf8(it.value().at(0))), attrs, client));
+            mOwnerItem = ResourceItem::Ptr(new ResourceItem(KLDAPCore::LdapDN(QString::fromUtf8(it.value().at(0))), attrs, client));
             connect(mOwnerItem.data(), &ResourceItem::searchFinished, this, &ResourceManagement::slotOwnerSearchFinished);
             mOwnerItem->startSearch();
             continue;
@@ -243,8 +241,8 @@ void ResourceManagement::slotOwnerSearchFinished()
     }
     mUi->groupOwner->setHidden(false);
 
-    const KLDAP::LdapObject &obj = mOwnerItem->ldapObject();
-    const KLDAP::LdapAttrMap &ldapAttrMap = obj.attributes();
+    const KLDAPCore::LdapObject &obj = mOwnerItem->ldapObject();
+    const KLDAPCore::LdapAttrMap &ldapAttrMap = obj.attributes();
     for (auto it = ldapAttrMap.cbegin(), end = ldapAttrMap.cend(); it != end; ++it) {
         const QString &key = it.key();
         if (key == QLatin1String("objectClass") || key == QLatin1String("owner") || key == QLatin1String("givenname") || key == QLatin1String("sn")) {
@@ -267,3 +265,5 @@ void ResourceManagement::slotDateChanged(const QDate &start, const QDate &end)
     }
     mAgendaView->showDates(start, end);
 }
+
+#include "moc_resourcemanagement.cpp"
